@@ -171,7 +171,9 @@ int main(int argc, char *argv[])
 	}
 	global_flags.num_cards = 1;  // For latency metrics.
 
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(58, 9, 100)
 	av_register_all();
+#endif
 	avformat_network_init();
 
 	HTTPD httpd;
